#ifndef _DB_REPOS_H_
#define _DB_REPOS_H_

#include <glib.h>
#include <sqlite3.h>

typedef struct {
    gchar *package;
    gchar *version;
    gchar *description;
    gchar *arch;
    gboolean installed;
    gboolean gui;
    gchar *location;
    gchar *reponame;
} PackageSearch;

typedef struct {
    GList *deps;
    GList *missing;
} DepsResolve;

enum PkgSearchFlags {
    PKG_NONE = 0,
    PKG_DEVEL = 1,
    PKG_NON_DEVEL = 2,
    PKG_GUI = 4,
    PKG_TEXT = 8,
    PKG_INSTALLED = 16,
    PKG_AVAILABLE = 32,
    PKG_SEARCH_DETAILS = 128,
    PKG_SEARCH_FILE = 256
};

gboolean box_db_attach_repo(sqlite3 *db, const gchar *destdir, const gchar *repo_name);
void box_db_detach_repo(sqlite3 *db, const gchar *repo_name);
gboolean box_db_attach_repos(sqlite3 *db, const gchar *destdir);
void box_db_detach_repos(sqlite3 *db);
GList* box_db_get_repos();

void box_db_repos_init(sqlite3 *db);
GList* box_db_repos_packages_for_upgrade(sqlite3 *db);
GList* box_db_repos_packages_search_by_data(sqlite3 *db, const gchar *package_name, const gchar *package_version);
GList* box_db_repos_packages_search_available(sqlite3 *db, const gchar *package, gint devel_flags);
GList* box_db_repos_packages_search_installed(sqlite3 *db, const gchar *package, gint devel_flags);
GList* box_db_repos_packages_search_all(sqlite3 *db, const gchar *package, gint devel_flags);
GList* box_db_repos_packages_search_one(sqlite3 *db, const gchar *package);
void box_db_repos_package_list_free(GList *list);
GList* box_db_repos_package_get_for_installation(sqlite3 *db, const gchar *package);

GList* box_db_repos_what_provide(sqlite3 *db, const gchar *dep);
GList* box_db_repos_what_require(sqlite3 *db, const gchar *dep);
GList* box_db_repos_what_require_many(sqlite3 *db, GList *list, const gchar *skip_name);
GList* box_db_repos_search_file(sqlite3 *db, const gchar *name);
GList* box_db_repos_search_file_with_filter(sqlite3 *db, const gchar *name, gint filter_flags);
GList* box_db_repos_search_man(sqlite3 *db, const gchar *name);
GList* box_db_repos_search_command(sqlite3 *db, const gchar *name);
GList* box_db_repos_search_header(sqlite3 *db, const gchar *name);
GList* box_db_repos_search_pkgconfig(sqlite3 *db, const gchar *name);

gchar* box_db_repos_get_files_string(sqlite3 *db, const gchar *name, const gchar *version);
GList* box_db_repos_get_depends(sqlite3 *db, const gchar *name);
GList* box_db_repos_get_requires(sqlite3 *db, const gchar *name);

DepsResolve* box_db_repos_resolve_deps(sqlite3 *db, GList *names);
DepsResolve* box_db_repos_resolve_deps_one(sqlite3 *db, gchar *name);

GList* box_db_repos_get_packages(sqlite3 *db);

DepsResolve* box_db_repos_resolve_deps_recurse(sqlite3 *db, const gchar *name, gboolean install_mode);
void box_db_repos_deps_free(DepsResolve *deps);

#endif
